use crate::innerlude::*;

pure_props! {
    /// Bulma [Footer](https://bulma.io/documentation/layout/footer/) Layout Element
    pub struct Footer {}
}

pure_wrapper!(Footer: <footer class="footer" />);
